@@ -241,7 +241,7 @@ function(Y,k=3,D=1,plot=TRUE,GOF=FALSE){
   return(
     list(estimates=result,out_of_control=out_control,
          Gradient=Gradient,Hessian=Hessian,Mineigenvalue_Hessian=min(eigen(Hessian)$value),
-         CM.test=CM.test,KS.test=KS.test)
+         CM.test=CM.test,KS.test=KS.test,log_likelihood = n*L_function(result[1],result[2],result[3]))
   )
   
 }
